<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://misite.com
 * @since             1.0.0
 * @package           Acf_For_Woocommerce
 *
 * @wordpress-plugin
 * Plugin Name:       Advanced Custom Fields for WooCommerce
 * Plugin URI:        https://gitlab.com/catsplugins/products/acf-for-wc-new
 * Description:       WooCommerce configurable product. Customize WooCommerce checkout fields. Add custom fields to user’s profile. All in one WooCommerce advanced custom fields.
 * Version:           v5.2.0
 * Author:            پرشین اسکریپت
 * Author URI:        https://www.persianscript.ir
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       acf-for-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */

require_once plugin_dir_path( __FILE__  ) . 'vendor/autoload.php';


/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-acf-for-woocommerce-activator.php
 */
function activate_acf_for_woocommerce() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-acf-for-woocommerce-activator.php';
    Acf_For_Woocommerce_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-acf-for-woocommerce-deactivator.php
 */
function deactivate_acf_for_woocommerce() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-acf-for-woocommerce-deactivator.php';
    Acf_For_Woocommerce_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_acf_for_woocommerce' );
register_deactivation_hook( __FILE__, 'deactivate_acf_for_woocommerce' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-acf-for-woocommerce.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
/**
 * Load scripts and style sheet for settings page
 */

function run_acf_for_woocommerce() {

    $plugin = new Acf_For_Woocommerce();
    $plugin->run();

}

run_acf_for_woocommerce();
